from DTPySide import *

def Information():
	return IconFromCurrentTheme("info.svg")

def Question():
	return IconFromCurrentTheme("help-circle.svg")

def Warning():
	return IconFromCurrentTheme("alert-triangle.svg")

def Error():
	return IconFromCurrentTheme("x-circle.svg")

def Happy():
	return IconFromCurrentTheme("smile.svg")

def Unhappy():
	return IconFromCurrentTheme("frown.svg")

def Heart():
	return IconFromCurrentTheme("heart.svg")

def HoloIcon1():
	return QIcon(":/icons/icon/holoicon1.ico")

def HoloIcon2():
	return QIcon(":/icons/icon/holoicon2.ico")

def Lock():
	return IconFromCurrentTheme("lock.svg")

def Unlock():
	return IconFromCurrentTheme("unlock.svg")

def Holo01():
	return QIcon(":/icons/icon/holo01.ico")